@@ -8,6 +8,7 @@
 */
 
 #include "koprefsdialogmain.h"
+
 #include "koprefs.h"
 #include <KPluginFactory>
 #include <QFormLayout>
@@ -91,6 +92,20 @@ KOPrefsDialogMain::KOPrefsDialogMain(QObject *parent, const KPluginMetaData &dat
     // show only resources, no agents
     manageAccountWidget->setCapabilityFilter(QStringList() << QStringLiteral("Resource"));
 
+#if HAVE_ACTIVITY_SUPPORT
+    auto activitiesFrame = new QFrame(widget());
+    tabWidget->addTab(activitiesFrame, QIcon::fromTheme(QStringLiteral("activities")), i18nc("@title:tab activities settings", "Activities"));
+
+    auto activitiesFrameLayout = new QVBoxLayout;
+    activitiesFrame->setLayout(activitiesFrameLayout);
+
+    mActivities = new QCheckBox(i18n("Enabled"), widget());
+    activitiesFrameLayout->addWidget(mActivities);
+    activitiesFrameLayout->addStretch(1);
+    mActivities->setChecked(KOPrefs::instance()->enabledActivities());
+    connect(mActivities, &QCheckBox::clicked, this, &KOPrefsDialogMain::slotWidChanged);
+#endif
+
     load();
 }
 
@@ -98,6 +113,9 @@ void KOPrefsDialogMain::usrWriteConfig()
 {
     Korganizer::KPrefsModule::usrWriteConfig();
     IncidenceEditorNG::IncidenceEditorSettings::self()->save();
+#if HAVE_ACTIVITY_SUPPORT
+    KOPrefs::instance()->setEnabledActivities(mActivities->isChecked());
+#endif
 }
 
 void KOPrefsDialogMain::toggleEmailSettings(bool on)
