@@ -198,7 +198,7 @@ void KOPrefsDialogPlugins::configureClicked(QAction *action)
 
         slotWidChanged();
     } else {
-        KMessageBox::error(widget(), i18nc("@info", "Unable to configure this plugin"), QStringLiteral("PluginConfigUnable"));
+        KMessageBox::error(widget(), QString(), i18nc("@info", "Unable to configure this plugin"));
     }
 }
 
